@@ -9,7 +9,7 @@ import os
 from collections.abc import Callable, Iterable
 from pathlib import Path
 from tarpy.utils import check_symlink, check_existence
-
+from tarpy.logger import LOGGER
 
 def should_exclude(path: str, exclusions: list[str]) -> bool:
     ''' Should Exclude
@@ -33,7 +33,7 @@ def should_exclude(path: str, exclusions: list[str]) -> bool:
     '''
     return any(fnmatch.fnmatch(path, exclude) for exclude in exclusions)
 
-def filter_paths(source: str, rule: Callable[str], exclusions: list[str]) -> Iterable[str]:
+def filter_paths(source: str, rule: Callable[..., str], exclusions: list[str]) -> Iterable[str]:
     ''' Filter Paths
 
     It is filtering out paths like defined in
@@ -75,7 +75,9 @@ def filtered_walk(source: Path, exclusions: list[str]) -> Iterable[str]:
         : Iterable[str]
         A Generator giving the filtered Paths.
     '''
-    for root, dirs, files in os.walk(source):
+    # Setting topdown to False in os.walk()
+    # improves the speed of the operation.
+    for root, dirs, files in os.walk(source, topdown=False):
         try:
             for directory in dirs:
                 tmp_dir = os.path.realpath(os.path.join(root, directory))
@@ -84,7 +86,9 @@ def filtered_walk(source: Path, exclusions: list[str]) -> Iterable[str]:
                 tmp_file = os.path.realpath(os.path.join(root, elem))
                 yield from filter_paths(tmp_file, should_exclude, exclusions)
 
-        except PermissionError:
+        except PermissionError as error_msg:
+            LOGGER.critical(error_msg)
             continue
-        except FileNotFoundError:
+        except FileNotFoundError as error_msg:
+            LOGGER.critical(error_msg)
             continue
